==> qmmp_2.2.3.orig.tar.bz2: qmmp-2.2.3/src/plugins/General/taskbar/translations/taskbar_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation>Greffon barre des tâches</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation>À propos du greffon barre des tâches</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation>Greffon barre des tâches pour Qmmp</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation>Ce greffon ajoute la visualisation du progrès de la lecture dans la barre des tâches de Windows</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_2.3.1.orig.tar.bz2: qmmp-2.3.1/src/plugins/General/taskbar/translations/taskbar_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation>Greffon barre des tâches</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation>À propos du greffon barre des tâches</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation>Greffon barre des tâches pour Qmmp</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation>Ce greffon ajoute la visualisation du progrès de la lecture dans la barre des tâches de Windows</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation>Basé sur le module QtWinExtras de Qt Toolkit</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation>QtWinExtras développeurs :</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation>Ivan Vizir &lt;define-true-false@yandex.com&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation>The Qt Company Ltd.</translation>
    </message>
</context>
</TS>
